"use strict";
/**
 * Cache Manager
 *
 * {
 * 	 src/styles/variables.css: {
 * 	 },
 *   all: {
 * 			--red: #355324,
 *      --green: #664435
 * 	 }
 * }
 */
Object.defineProperty(exports, "__esModule", { value: true });
class CacheManager {
    constructor() {
        this.cachedVariablesByWorkspace = new Map();
        this.allVariables = new Map();
    }
    get(key, filePath) {
        var _a, _b;
        if (filePath) {
            return (_a = this.cachedVariablesByWorkspace[filePath]) === null || _a === void 0 ? void 0 : _a.get(key);
        }
        return (_b = this.allVariables) === null || _b === void 0 ? void 0 : _b.get(key);
    }
    getAll() {
        return this.allVariables;
    }
    getCachedVars() {
        return this.cachedVariablesByWorkspace;
    }
    getAllForWorkspace(currentWorkspace) {
        const workspace = this.cachedVariablesByWorkspace.get(currentWorkspace);
        if (!workspace)
            return new Map();
        const variables = new Map();
        workspace.forEach((file) => file.forEach((value, key) => {
            variables.set(key, value);
        }));
        return variables;
    }
    set(filePath, key, value, workspace) {
        var _a;
        if (!this.cachedVariablesByWorkspace.get(workspace)) {
            this.cachedVariablesByWorkspace.set(workspace, new Map());
        }
        if (!this.cachedVariablesByWorkspace.get(workspace).get(filePath)) {
            this.cachedVariablesByWorkspace.get(workspace).set(filePath, new Map());
        }
        (_a = this.allVariables) === null || _a === void 0 ? void 0 : _a.set(key, value);
        this.cachedVariablesByWorkspace
            .get(workspace)
            .get(filePath)
            .set(key, value);
    }
    clearFileCache(filePath, workspace) {
        var _a, _b, _c, _d, _e;
        (_c = (_b = (_a = this.cachedVariablesByWorkspace) === null || _a === void 0 ? void 0 : _a[workspace]) === null || _b === void 0 ? void 0 : _b[filePath]) === null || _c === void 0 ? void 0 : _c.forEach((_, key) => {
            var _a;
            (_a = this.allVariables) === null || _a === void 0 ? void 0 : _a.delete(key);
        });
        (_e = (_d = this.cachedVariablesByWorkspace) === null || _d === void 0 ? void 0 : _d[filePath]) === null || _e === void 0 ? void 0 : _e.clear();
    }
    clearWorkspaceCache(workspace) {
        this.cachedVariablesByWorkspace.get(workspace).forEach((file) => file.forEach((_, key) => {
            var _a;
            (_a = this.allVariables) === null || _a === void 0 ? void 0 : _a.delete(key);
        }));
        this.cachedVariablesByWorkspace.get(workspace).clear();
    }
    clearAllCache() {
        var _a;
        (_a = this.allVariables) === null || _a === void 0 ? void 0 : _a.clear();
        this.cachedVariablesByWorkspace.clear();
    }
}
exports.default = CacheManager;
//# sourceMappingURL=CacheManager.js.map